const { format } = require("winston");

/**
 * Returns the default console format.
 * @see https://github.com/winstonjs/winston#formats
 *
 * @param   {String} [source="default"]
 */
module.exports = function(source = "default") {
	const console_format = format.combine(
		format.colorize(),
		format.timestamp(),
		format.label({ label: source }),
		format.splat(),
		format.printf(info => {
			if (typeof info.message === "string" || info.message instanceof String) {
				// If the message is a string.
				return `${info.timestamp} [${info.label.toUpperCase()}.${
					process.pid
				}] ${info.level}: ${info.message}`;
			} else {
				// If the message is an Object.
				return `${info.timestamp} [${info.label.toUpperCase()}.${
					process.pid
				}] ${info.level}: ${JSON.stringify(info.message)}`;
			}
		})
	);

	return console_format;
};
