const fs = require("fs");
var path = require("path");
const daily_rotate_file = require("winston-daily-rotate-file");

const get_log_format = require("./get_log_format.js");
const on_rotation = require("./on_rotation.js");

const default_params = {
	format: get_log_format(),
	level: process.env.NODE_LOG_LEVEL || "silly",
	filename: "combined.log.%DATE%",
	dirname: process.env.LOGS_PATH || path.dirname(require.main.filename),
	datePattern: "DD-MM-YYYY",
	maxFiles: "30"
	// maxsize: '1000',
	// zippedArchive: true
};

/**
 * Returns a transport object for the log file.
 * @see https://github.com/winstonjs/winston#transports
 *
 * @param   {Object} [params={}]
 *
 * The params object will be merged with
 * ```
 * const default_params = {
 * 	format: Object,
 *	level: process.env.NODE_LOG_LEVEL || "silly",
 *	filename: "combined.log.%DATE%",
 *	dirname: process.env.LOGS_PATH || path.dirname(require.main.filename),
 *	datePattern: "DD-MM-YYYY",
 *	maxFiles: "30"
 *	// maxsize: '1000',
 *	// zippedArchive: true
 * }
 * ```
 */
module.exports = function get_log_transport(params = {}) {
	const final_params = Object.assign({}, default_params, params);

	// Create the directory if it does not exist
	if (!fs.existsSync(final_params.dirname)) {
		fs.mkdirSync(final_params.dirname);
	}

	const log_transport = new daily_rotate_file(final_params);
	log_transport.on("rotate", on_rotation);
	return log_transport;
};
