const winston = require("winston");

const get_console_transport = require("./get_console_transport.js");
const {
	get_errors_log_transport,
	get_combined_log_transport
} = require("./get_log_transports.js");
const custom_levels = require("./custom_levels.js");

function get_logger(source) {
	const logger = winston.createLogger({
		transports: [
			get_errors_log_transport(source),
			get_combined_log_transport(source)
		]
	});

	if (process.env.NODE_ENV !== "production") {
		logger.add(get_console_transport(source));
	}

	winston.addColors(custom_levels);
	return logger;
}

module.exports = get_logger;

const bot_himself_logger = require("./bot_himself");
const exchanges_loggers = require("./exchanges");
const trading_strategies_loggers = require("./trading_strategies");
const databases_loggers = require("./databases");

const loggers = Object.assign(bot_himself_logger, {
	exchanges: exchanges_loggers,
	trading_strategies: trading_strategies_loggers,
	databases: databases_loggers
});

module.exports = loggers;

// let logtest = winston.loggers.get('binance');
// console.log(logtest.transports)

// let logtest2 = winston.loggers.get('bittrex');

// logtest.info('\nblabla\n');
// logtest.error('WARNING !!\n\n');
// logtest2.error('WARNING !!\n\n')
